diff --git a/Marlin/ultralcd.cpp b/Marlin/ultralcd.cpp
index b737f1b9de..f246a5c636 100644
--- a/Marlin/ultralcd.cpp
+++ b/Marlin/ultralcd.cpp
@@ -5398,9 +5398,8 @@ void lcd_reset_alert_level() { lcd_status_message_level = 0; }
       }
       #if ENABLED(AUTO_BED_LEVELING_UBL)
         if (lcd_external_control) {
-          ubl.encoder_diff = encoderDiff;   // Make the encoder's rotation available to G29's Mesh Editor
-          encoderDiff = 0;                  // We are going to lie to the LCD Panel and claim the encoder
-                                            // knob has not turned.
+          ubl.encoder_diff = encoderDiff;   // Make encoder rotation available to UBL G29 mesh editing.
+          encoderDiff = 0;                  // Hide the encoder event from the current screen handler.
         }
       #endif
       lastEncoderBits = enc;
diff --git a/Marlin/G26_Mesh_Validation_Tool.cpp b/Marlin/G26_Mesh_Validation_Tool.cpp
index 88a6252e4f..d1f63cba58 100644
--- a/Marlin/G26_Mesh_Validation_Tool.cpp
+++ b/Marlin/G26_Mesh_Validation_Tool.cpp
@@ -274,15 +274,14 @@
                                     // action to give the user a more responsive 'Stop'.
           set_destination_from_current();
           idle();
-          MYSERIAL.flush();  // G26 takes a long time to complete.   PronterFace can
-                             // over run the serial character buffer with M105's without
-                             // this fix
+          MYSERIAL.flush();  // G26 takes a long time to complete. PronterFace may
+                             // overwhelm the serial buffer with M105's without this fix.
         }
 
         wait_for_release();
 
-        strcpy_P(lcd_status_message, PSTR("Done Priming")); // We can't do lcd_setstatusPGM() without having it continue;
-                                                            // So... We cheat to get a message up.
+        strcpy_P(lcd_status_message, PSTR("Done Priming")); // Hack to get the message up. May be obsolete.
+
         lcd_setstatusPGM(PSTR("Done Priming"), 99);
         lcd_quick_feedback(true);
         lcd_external_control = false;